# scd30-exporter

Prometheus exporter for Adafruit SCD-30 - NDIR CO2 Temperature and Humidity Sensor.


## Installing

```sh
pip3 install scd30-exporter
```

## Running

```sh
scd30-exporter --port 8000 --interval 10
```


## Developing

See [DEVELOPING.md](DEVELOPING.md)
